package com.example.wfwebapi.controller;

import com.example.wfwebapi.exception.ResourceNotFoundException;
import com.example.wfwebapi.model.Image;
import com.example.wfwebapi.repository.ImageRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/v1/image")
public class ImageController {

    @Autowired
    private ImageRepository imageRepository;

    @GetMapping("/{id}")
    public Image getImageById(@PathVariable Long id) {
        return imageRepository.findById(id)
                .orElseThrow(() -> new ResourceNotFoundException("Image non trouvée : " + id));
    }

    @GetMapping("/all")
    public List<Image> getAllImages() {
        return imageRepository.findAll();
    }

    @PostMapping
    public Image createImage(@RequestBody Image image) {
        return imageRepository.save(image);
    }

    @PutMapping
    public Image updateImage(@RequestBody Image updatedImage) {
        return imageRepository.findById(updatedImage.getId())
                .map(img -> {
                    img.setImgPath(updatedImage.getImgPath());
                    return imageRepository.save(img);
                }).orElseThrow(() -> new ResourceNotFoundException("Image non trouvée : " + updatedImage.getId()));
    }

    @DeleteMapping
    public void deleteImage(@RequestParam Long id) {
        if (!imageRepository.existsById(id))
            throw new ResourceNotFoundException("Image non trouvée : " + id);
        imageRepository.deleteById(id);
    }
}
