package com.example.wfwebapi.controller;

import com.example.wfwebapi.exception.ResourceNotFoundException;
import com.example.wfwebapi.model.Question;
import com.example.wfwebapi.repository.QuestionRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/api/v1/question")
public class QuestionController {

    @Autowired
    private QuestionRepository questionRepository;

    @GetMapping("/{id}")
    public Question getQuestionById(@PathVariable Long id) {
        return questionRepository.findById(id)
                .orElseThrow(() -> new ResourceNotFoundException("Question non trouvée : " + id));
    }

    @PostMapping
    public Question createQuestion(@RequestBody Question question) {
        return questionRepository.save(question);
    }

    @PutMapping
    public Question updateQuestion(@RequestBody Question updatedQuestion) {
        return questionRepository.findById(updatedQuestion.getId())
                .map(q -> {
                    q.setTexte(updatedQuestion.getTexte());
                    q.setAnswerA(updatedQuestion.getAnswerA());
                    q.setAnswerB(updatedQuestion.getAnswerB());
                    q.setAnswerC(updatedQuestion.getAnswerC());
                    q.setAnswerD(updatedQuestion.getAnswerD());
                    q.setCAnswer(updatedQuestion.getCAnswer());
                    return questionRepository.save(q);
                }).orElseThrow(() -> new ResourceNotFoundException("Question non trouvée : " + updatedQuestion.getId()));
    }

    @DeleteMapping
    public void deleteQuestion(@RequestParam Long id) {
        if (!questionRepository.existsById(id))
            throw new ResourceNotFoundException("Question non trouvée : " + id);
        questionRepository.deleteById(id);
    }
}
