package com.example.wfwebapi.controller;

import com.example.wfwebapi.exception.ResourceNotFoundException;
import com.example.wfwebapi.model.Quiz;
import com.example.wfwebapi.repository.QuizRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/v1/quiz")
public class QuizController {

    @Autowired
    private QuizRepository quizRepository;

    @GetMapping
    public List<Quiz> getAllQuiz() {
        return quizRepository.findAll();
    }

    @GetMapping("/{id}")
    public Quiz getQuizById(@PathVariable Long id) {
        return quizRepository.findById(id)
                .orElseThrow(() -> new ResourceNotFoundException("Quiz non trouvé : " + id));
    }

    @PostMapping
    public Quiz createQuiz(@RequestBody Quiz quiz) {
        return quizRepository.save(quiz);
    }

    @PutMapping
    public Quiz updateQuiz(@RequestBody Quiz updatedQuiz) {
        return quizRepository.findById(updatedQuiz.getId())
                .map(q -> {
                    q.setTitle(updatedQuiz.getTitle());
                    q.setImage(updatedQuiz.getImage());
                    return quizRepository.save(q);
                }).orElseThrow(() -> new ResourceNotFoundException("Quiz non trouvé : " + updatedQuiz.getId()));
    }

    @DeleteMapping
    public void deleteQuiz(@RequestParam Long id) {
        if (!quizRepository.existsById(id))
            throw new ResourceNotFoundException("Quiz non trouvé : " + id);
        quizRepository.deleteById(id);
    }
}
