package com.example.wfwebapi.controller;

import java.util.List;
import java.util.stream.Collectors;
import com.example.wfwebapi.assembler.QuoteModelAssembler;
import com.example.wfwebapi.exception.ResourceNotFoundException;
import com.example.wfwebapi.model.Quote;
import com.example.wfwebapi.repository.QuoteRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.hateoas.CollectionModel;
import org.springframework.hateoas.EntityModel;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/api/v1/quote")
public class QuoteController {

    @Autowired
    private QuoteRepository quoteRepository;

    @Autowired
    private QuoteModelAssembler assembler;

    @GetMapping("/{id}")
    public EntityModel<Quote> getQuoteById(@PathVariable Long id) {
        Quote quote = quoteRepository.findById(id)
                .orElseThrow(() -> new ResourceNotFoundException("Citation non trouvée : " + id));
        return assembler.toModel(quote);
    }

    @GetMapping("/all")
    public CollectionModel<EntityModel<Quote>> getAllQuotes(@RequestParam int index, @RequestParam int count) {
        List<EntityModel<Quote>> quotes = quoteRepository.findAll(PageRequest.of(index, count))
                .stream().map(assembler::toModel)
                .collect(Collectors.toList());
        return CollectionModel.of(quotes);
    }

    @GetMapping("/dailyquote")
    public EntityModel<Quote> getDailyQuote(@RequestParam int year, @RequestParam int month,
                                            @RequestParam int day, @RequestParam String lang) {
        // Exemple : renvoi la première citation correspondant à la langue
        Quote quote = quoteRepository.findAll().stream()
                .filter(q -> q.getLangue().equalsIgnoreCase(lang))
                .findFirst()
                .orElseThrow(() -> new ResourceNotFoundException("Aucune citation trouvée pour la langue " + lang));
        return assembler.toModel(quote);
    }

    @PostMapping
    public EntityModel<Quote> createQuote(@RequestBody Quote newQuote) {
        Quote quote = quoteRepository.save(newQuote);
        return assembler.toModel(quote);
    }

    @PutMapping
    public EntityModel<Quote> updateQuote(@RequestBody Quote updatedQuote) {
        Quote quote = quoteRepository.findById(updatedQuote.getId())
                .map(q -> {
                    q.setContent(updatedQuote.getContent());
                    q.setLangue(updatedQuote.getLangue());
                    q.setLikes(updatedQuote.getLikes());
                    q.setIsValide(updatedQuote.getIsValide());
                    q.setReason(updatedQuote.getReason());
                    q.setCaracter(updatedQuote.getCaracter());
                    q.setSource(updatedQuote.getSource());
                    q.setUserVerif(updatedQuote.getUserVerif());
                    return quoteRepository.save(q);
                }).orElseThrow(() -> new ResourceNotFoundException("Citation non trouvée : " + updatedQuote.getId()));
        return assembler.toModel(quote);
    }

    @DeleteMapping("/delete")
    public void deleteQuote(@RequestParam Long idQuote) {
        if (!quoteRepository.existsById(idQuote))
            throw new ResourceNotFoundException("Citation non trouvée : " + idQuote);
        quoteRepository.deleteById(idQuote);
    }
}
