package com.example.wfwebapi.controller;

import com.example.wfwebapi.exception.ResourceNotFoundException;
import com.example.wfwebapi.model.RecordQuiz;
import com.example.wfwebapi.model.RecordQuizId;
import com.example.wfwebapi.repository.RecordQuizRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/api/v1/recordquiz")
public class RecordQuizController {

    @Autowired
    private RecordQuizRepository recordQuizRepository;

    @GetMapping
    public RecordQuiz getRecord(@RequestParam Long user, @RequestParam Long quiz) {
        RecordQuizId id = new RecordQuizId(user, quiz);
        return recordQuizRepository.findById(id)
                .orElseThrow(() -> new ResourceNotFoundException("RecordQuiz non trouvé"));
    }

    @PostMapping
    public RecordQuiz createRecord(@RequestBody RecordQuiz recordQuiz) {
        return recordQuizRepository.save(recordQuiz);
    }

    @PutMapping
    public RecordQuiz updateRecord(@RequestBody RecordQuiz recordQuiz) {
        RecordQuizId id = recordQuiz.getId();
        if (!recordQuizRepository.existsById(id))
            throw new ResourceNotFoundException("RecordQuiz non trouvé");
        return recordQuizRepository.save(recordQuiz);
    }

    @DeleteMapping
    public void deleteRecord(@RequestParam Long user, @RequestParam Long quiz) {
        RecordQuizId id = new RecordQuizId(user, quiz);
        if (!recordQuizRepository.existsById(id))
            throw new ResourceNotFoundException("RecordQuiz non trouvé");
        recordQuizRepository.deleteById(id);
    }
}
