package com.example.wfwebapi.controller;

import com.example.wfwebapi.exception.ResourceNotFoundException;
import com.example.wfwebapi.model.Source;
import com.example.wfwebapi.repository.SourceRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/api/v1/source")
public class SourceController {

    @Autowired
    private SourceRepository sourceRepository;

    @GetMapping("/{id}")
    public Source getSourceById(@PathVariable Long id) {
        return sourceRepository.findById(id)
                .orElseThrow(() -> new ResourceNotFoundException("Source non trouvée : " + id));
    }

    @PostMapping
    public Source createSource(@RequestBody Source source) {
        return sourceRepository.save(source);
    }

    @PutMapping
    public Source updateSource(@RequestBody Source updatedSource) {
        return sourceRepository.findById(updatedSource.getId())
                .map(s -> {
                    s.setTitle(updatedSource.getTitle());
                    s.setDateS(updatedSource.getDateS());
                    return sourceRepository.save(s);
                }).orElseThrow(() -> new ResourceNotFoundException("Source non trouvée : " + updatedSource.getId()));
    }

    @DeleteMapping
    public void deleteSource(@RequestParam Long id) {
        if (!sourceRepository.existsById(id))
            throw new ResourceNotFoundException("Source non trouvée : " + id);
        sourceRepository.deleteById(id);
    }
}
